@@ -30,8 +30,8 @@
 extern "C" {
 #endif
 
-#define BLKID_VERSION   "2.40.1"
-#define BLKID_DATE      "06-May-2024"
+#define BLKID_VERSION   "2.40.4"
+#define BLKID_DATE      "13-Jan-2025"
 
 /**
  * blkid_dev:
